@@ -88,10 +88,19 @@ def add_request_task_response_status_codes(request: RequestTask, status_list: st
         request.response.add_status_code(int(status.strip()))
 
 
-def add_request_task(context: Context, method: RequestMethod, source: Optional[str] = None, name: Optional[str] = None, endpoint: Optional[str] = None) -> None:
+def add_request_task(
+    context: Context,
+    method: RequestMethod,
+    source: Optional[str] = None,
+    name: Optional[str] = None,
+    endpoint: Optional[str] = None,
+    in_scenario: Optional[bool] = True,
+) -> List[Tuple[RequestTask, Dict[str, str]]]:
     grizzly = cast(GrizzlyContext, context.grizzly)
     scenario_tasks_count = len(grizzly.scenario.tasks)
 
+    request_tasks: List[Tuple[RequestTask, Dict[str, str]]] = []
+
     table: List[Optional[Row]]
     content_type: Optional[TransformerContentType] = None
 
@@ -128,11 +137,11 @@ def add_request_task(context: Context, method: RequestMethod, source: Optional[s
 
         if row is not None:
             for key, value in row.as_dict().items():
+                substitutes.update({key: value})
                 endpoint = endpoint.replace(f'{{{{ {key} }}}}', value)
                 if name is not None:
                     name = name.replace(f'{{{{ {key} }}}}', value)
                 if source is not None:
-                    substitutes.update({key: value})
                     source = source.replace(f'{{{{ {key} }}}}', value)
 
         request_task = create_request_task(context, method, source, endpoint, name, substitutes=substitutes)
@@ -143,7 +152,12 @@ def add_request_task(context: Context, method: RequestMethod, source: Optional[s
         name = orig_name
         source = orig_source
 
-        grizzly.scenario.tasks.append(request_task)
+        if in_scenario:
+            grizzly.scenario.tasks.append(request_task)
+        else:
+            request_tasks.append((request_task, substitutes,))
+
+    return request_tasks
 
 
 def get_matches(
