@@ -10,3 +10,11 @@ from .messagequeue import MessageQueueUser
 from .servicebus import ServiceBusUser
 from .sftp import SftpUser
 from .blobstorage import BlobStorageUser
+
+__all__ = [
+    'RestApiUser',
+    'MessageQueueUser',
+    'ServiceBusUser',
+    'SftpUser',
+    'BlobStorageUser',
+]
